@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TestRunner.h 2388 2007-03-10 11:34:50Z svn $
+ * $Id: TestRunner.h 2501 2007-07-06 15:27:30Z svn $
  *****************************************************************************/
 
 #ifndef TEST_RUNNER_H
@@ -30,6 +30,7 @@
 
 #include "Environment.h"
 
+#include <string>
 #include <iostream>
 #include <iomanip>
 
@@ -109,7 +110,7 @@ void show_test_name(const char *test_name)
  * @param[in] key アイテムのキー
  * @param[in] value アイテムの値
  */
-void show_item(const char *key, const char *value)
+void show_item(std::string key, std::string value)
 {
     cerr << setw(24) << setiosflags(ios::left) << key << ": ";
     cerr << value << endl;
