@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MultipartMessageParser.cpp 2296 2006-12-24 02:58:57Z svn $
+ * $Id: MultipartMessageParser.cpp 2475 2007-07-01 05:35:29Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -90,12 +90,13 @@ MultipartMessageParser<R, W>::FILE_NAME_TEMPLATE[]  = "post";
  * public メソッド
  *****************************************************************************/
 template<class R, class W>
-MultipartMessageParser<R, W>::MultipartMessageParser(apr_pool_t *pool, PostReaderClass& reader,
-                                   const char *file_dir_path,
-                                   apr_size_t max_text_size,
-                                   apr_uint64_t max_file_size,
-                                   apr_size_t max_item_num,
-                                   apr_size_t file_offset)
+MultipartMessageParser<R, W>::MultipartMessageParser(apr_pool_t *pool,
+                                                     PostReaderClass& reader,
+                                                     const char *file_dir_path,
+                                                     apr_size_t max_text_size,
+                                                     apr_uint64_t max_file_size,
+                                                     apr_size_t max_item_num,
+                                                     apr_size_t file_offset)
   : pool_(pool),
     reader_(reader),
     buffer_(READ_BLOCK_SIZE * 2), // 2 以上じゃないとまずい
@@ -120,7 +121,7 @@ MultipartMessageParser<R, W>::~MultipartMessageParser()
 template<class R, class W>
 typename MultipartMessageParser<R, W>::content_t *
 MultipartMessageParser<R, W>::get_content(apr_array_header_t *content_array,
-                                 const char *name)
+                                          const char *name)
 {
     content_t *contents;
 
