@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteLocker.cpp 2511 2007-07-07 06:43:31Z svn $
+ * $Id: ReadWriteLocker.cpp 2540 2007-07-21 15:21:47Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -30,7 +30,7 @@
 #include "ReadWriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ReadWriteLocker.cpp 2511 2007-07-07 06:43:31Z svn $");
+SOURCE_INFO_ADD("$Id: ReadWriteLocker.cpp 2540 2007-07-21 15:21:47Z svn $");
 
 
 /******************************************************************************
@@ -44,7 +44,7 @@ bool ReadWriteLocker::should_timeout(apr_uint32_t status)
     curr_age = status & AGE_MASK;
     curr_time = apr_time_now();
 
-    if ((start_age_ == 0) || is_timeout(curr_age, start_age_)) {
+    if ((start_age_ == INVALID_AGE) || is_timeout(curr_age, start_age_)) {
         start_age_ = curr_age;
         start_time_ = curr_time;
 
@@ -52,6 +52,8 @@ bool ReadWriteLocker::should_timeout(apr_uint32_t status)
     }
 
     if (UNLIKELY(apr_time_sec(curr_time - start_time_) > TIMEOUT_SEC)) {
+        std::cerr << "[warn] " PACKAGE_NAME;
+        std::cerr << ": Lock timeout occurred" << std::endl;
         return true;
     } else {
         return false;
