@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 2432 2007-05-20 10:14:27Z svn $
+ * $Id: TemplateExecutor.cpp 2548 2007-08-06 14:16:57Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -41,7 +41,7 @@
 using namespace std;
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2432 2007-05-20 10:14:27Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2548 2007-08-06 14:16:57Z svn $");
 #endif
 
 #ifdef DEBUG_TemplateExecutor
@@ -729,7 +729,7 @@ void run_exec(apr_pool_t *pool, UploadItemList *item_list,
         executor_is_trace = true;
     }
 
-    CGIResponseWriter writer;
+    CGIResponseWriter writer(pool);
     TemplateExecutorImpl executor(pool, writer);
 
     executor.exec(up_template.get_node_tree(), var_creator.get_variables(),
