@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2491 2007-07-04 13:17:09Z svn $
+ * $Id: UploadItemManager.cpp 2508 2007-07-06 22:47:18Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,6 @@
 #include "UploadItemList.h"
 #include "ThumbnailList.h"
 #include "TemporaryPool.h"
-#include "Locker.h"
 #include "ReadLocker.h"
 #include "WriteLocker.h"
 #include "Message.h"
@@ -49,7 +48,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2491 2007-07-04 13:17:09Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2508 2007-07-06 22:47:18Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -70,7 +69,7 @@ SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2491 2007-07-04 13:17:09Z svn $");
 #endif
 
 const apr_size_t UploadItemManager::SYNC_FACTOR = 32;
-const apr_size_t UploadItemManager::SYNC_LIMIT  = 100;
+const apr_size_t UploadItemManager::SYNC_LIMIT  = 200;
 
 
 /******************************************************************************
@@ -118,8 +117,9 @@ void UploadItemManager::sync_all_item(apr_pool_t *pool, apr_size_t sync_limit)
 {
     UploadItem::header_t *header;
     apr_size_t synced_count;
+    ReadLocker manager_locker(lock_);
 
-    // カウンタの値は atomic に変更されるので，ロックは不要
+    REQUIRE_MANAGER_LOCKED();
 
     synced_count = 0;
     for (apr_size_t i = 0; i < item_list_->size(); i++) {
@@ -314,15 +314,15 @@ void UploadItemManager::clear_shm()
 
 void UploadItemManager::init_shm()
 {
-    mtime_ = AS_TIME(this + 1);
-    lock_ = AS_ATOMIC(mtime_ + 1);
-    age_ = AS_SIZE(lock_ + 1);
+    lock_ = AS_ATOMIC(this + 1);
+    mtime_ = AS_TIME(lock_ + 1);
+    age_ = AS_SIZE(mtime_ + 1);
 
 #ifdef __INTEL_COMPILER
 #pragma warning(disable:1684)
 #endif
     ASSERT_EQUAL(AS_CHAR(age_ + 1),
-                 AS_CHAR(mtime_) +
+                 AS_CHAR(lock_) +
                  (get_memory_size() - sizeof(UploadItemManager)));
 #ifdef __INTEL_COMPILER
 #pragma warning(default:1684)
