@@ -17,7 +17,7 @@ export SF_PASS
 
 run() {
     echo "$0: running \`$@'"
-    $@ || exit
+    $@ || exit -1
 }
 
 run ./configure --enable-thumbnail
